#! /bin/perl
# Description : Creates an OTU table with taxonomy from ESPRIT consensus output table file and Mothur classify.seqs output file
# Usage : perl OTU_tables_format.pl esprit_consensus_table.txt mothur_classify_seqs.taxonomy output.tsv
# Author : PEGASE-biosciences 
# http://www.pegase-biosciences.com/collaborations/blastocystis-gut-microbiota/

# ESPRIT consensus output table example :
# UGSJ7_03269_01386	2
# UGSJ7_01430_00328	3
# UGSJ7_01967_01611	22
# UGSJ7_01191_02256	36
# UGSJ7_01649_02403	18

# mothur classify.seqs output example :
# UGSJ7_00612_00682	Bacteria(100);Firmicutes(100);Clostridia(100);Clostridiales(100);Ruminococcaceae(98);Sporobacter(42);unclassified;unclassified;
# UGSJ7_02571_00935	Bacteria(100);Firmicutes(99);Clostridia(98);Clostridiales(98);Ruminococcaceae(95);unclassified_Ruminococcaceae(71);unclassified;unclassified;
# UGSJ7_00512_02400	Bacteria(100);Firmicutes(59);Clostridia(51);Clostridiales(51);Ruminococcaceae(33);Sporobacter(27);unclassified;unclassified;
# UGSJ7_02304_00828	Bacteria(100);Bacteroidetes(92);Bacteroidia(58);Bacteroidales(58);Prevotellaceae(11);Paraprevotella(11);unclassified;unclassified;
# UGSJ7_02618_01847	Bacteria(100);Firmicutes(58);Clostridia(54);Clostridiales(54);Ruminococcaceae(46);Papillibacter(13);unclassified;unclassified;

# Script output :
# UGSJ7_03761_02407	12405	UGSJ7_03761_02407	Bacteria(100);Bacteroidetes(100);Bacteroidia(100);Bacteroidales(100);Bacteroidaceae(100);Bacteroides(100);unclassified;unclassified;
# UGSJ7_00477_02119	5507	UGSJ7_00477_02119	Bacteria(100);Bacteroidetes(100);Bacteroidia(100);Bacteroidales(100);Bacteroidaceae(100);Bacteroides(100);unclassified;unclassified;
# UGSJ7_02970_00691	2059	UGSJ7_02970_00691	Bacteria(100);Bacteroidetes(100);Bacteroidia(100);Bacteroidales(100);Bacteroidaceae(100);Bacteroides(100);unclassified;unclassified;
# UGSJ7_00617_00835	1459	UGSJ7_00617_00835	Bacteria(100);Bacteroidetes(100);Bacteroidia(100);Bacteroidales(100);Bacteroidaceae(100);Bacteroides(100);unclassified;unclassified;
# UGSJ7_00975_00849	954	UGSJ7_00975_00849	Bacteria(100);Bacteroidetes(100);Bacteroidia(100);Bacteroidales(100);Porphyromonadaceae(100);Parabacteroides(100);unclassified;unclassified;


my $consensus = $ARGV[0];
my $mothur = $ARGV[1];
my $output = $ARGV[2];

my %reads_per_otu = {};
my @line=();

open(my $in, $consensus);
while(<$in>) {
	chomp($_);
	@line=split("\t",$_);
	$reads_per_otu{$line[0]}=$line[1];
}
close($in);

open($in,$mothur);
open(my $out,">$output");
while(<$in>) {
	chomp($_);
	@line=split("\t",$_);
	print $out "$line[0]\t$reads_per_otu{$line[0]}\t$line[0]\t$line[1]\n";
}
close($in);
close($out);
