#! /usr/bin/python
# Description : Merges all OTU tables intp one table
# Usage : python OTU_tables_merge.py tax_directory output.tsv
#   tax_directory is a directory countaining all tsv OTU tables from all samples

# To be able to read output OTU table in STAMP, each taxa name must be in the Greengenes nomenclature convention
# (k__taxa = kingdom, p__ = phylum, c__ = class, o__ = order, f__ = family, g__ = genus, s__ = specie)
# WARNING : those prefix are added automatically (l. 24 t 39) according to the position of the taxa in the taxonomy sequence
# HOWEVER this conversion must be manually checked, as it is disrupted when subtaxa are present
# (eg : subfamilies will be annotated as genuses (g__))

# Author : PEGASE-biosciences 
# http://www.pegase-biosciences.com/collaborations/blastocystis-gut-microbiota/

import os, sys, string

def normalize_tax(tax):
	tax = tax.split(";")
	rettax = ''
	for i in range(0, len(tax)):

		if tax[i] == '':
			continue
		if i == 0:
			rettax += 'k__'
		if i == 1:
			rettax += 'p__'
		if i == 2:
			rettax += 'c__'
		if i == 3:
			rettax += 'o__'
		if i == 4:
			rettax += 'f__'
		if i == 5:
			rettax += 'g__'
		if i == 6:
			rettax += 's__'
		if i > 6:
			continue
												
		if '(' in tax[i]:
			rettax += tax[i][:tax[i].index('(')]+';'
		else:
			rettax += tax[i]+';'
	return rettax

if __name__ == "__main__":
	taxodir = sys.argv[1]
	samplesdict = {}
	taxlist = []
	for filename in os.listdir(taxodir):
		fd = open(taxodir+"/"+filename)
		fileid = filename.replace(".tsv", "")
		samplesdict[fileid] = {}
		for line in fd:
			line = line.strip().split("\t")
			tax = normalize_tax(line[3])
			if tax not in taxlist:
				taxlist.append(tax)
			if tax not in samplesdict[fileid]:
				samplesdict[fileid][tax] = 0
			samplesdict[fileid][tax] += int(line[1])
		fd.close()

	outfile = open(sys.argv[2], 'w')
	outfile.write('\t'.join(sorted(samplesdict.keys()))+'\ttaxonomy\n')
	for tax in taxlist:
		for key in sorted(samplesdict.keys()):
			try:
				outfile.write(str(samplesdict[key][tax])+'\t')
			except KeyError:
				outfile.write('0\t')
		outfile.write(tax+'\n')
	outfile.close()
