# Description : Generates rarefaction curves from ESPRIT do_stat output and Mothur unique.seqs output
# Usage : Replace input and output files names (sample.names, sample_esprit_do_stat.txt and sample_rarefaction_curve.pdf)
#   then execute the script in R :
#   R --vanilla --slave $* < rarefaction.R
# Author : PEGASE-biosciences 
# http://www.pegase-biosciences.com/collaborations/blastocystis-gut-microbiota/

# Input files
# sample.names # Mothur output names file (after the last unique.seqs step)
# sample_esprit_do_stat.txt # ESPRIT do_stat output

# Output file
# sample_rarefaction_curve.pdf - Rarefaction curve of the sample

# Errors are redirected to stdout
options( show.error.messages=F, error = function () { cat( geterrmessage(), file=stderr() ); q( "no", 1, F ) } )

seq = read.table("sample.names")
nb_seq = length(seq[,1])

data = read.table("sample_esprit_do_stat.txt")
data = t(data)
colnames(data) = data[1,]
data = as.data.frame(data)
data = data[2:length(data[,1]),]

data[,colnames(data) == "Distance"] = round(as.numeric(as.character(data[,colnames(data) == "Distance"])) * nb_seq)
colnames(data) = c("Distance",paste("X",colnames(data[2:length(colnames(data))]),sep=""))

pdf( "sample_rarefaction_curve.pdf" )
plot(data[,colnames(data) == "Distance"], as.numeric(as.character(data[,colnames(data) == "X0.03"])), main="sample.names", type="l", xlab="# sequences sampled", ylab="Observed OTUs", col="blue")

if( length(as.numeric(as.character(data[,colnames(data) == "X0.05"]))) > 0){ 
	lines(data[,colnames(data) == "Distance"], as.numeric(as.character(data[,colnames(data) == "X0.05"])), type="l", col="green")
}

if( length(as.numeric(as.character(data[,colnames(data) == "X0.07"]))) > 0){ 
	lines(data[,colnames(data) == "Distance"], as.numeric(as.character(data[,colnames(data) == "X0.07"])), type="l", col="red")
}

if( length(as.numeric(as.character(data[,colnames(data) == "X0.09"]))) > 0){ 
	lines(data[,colnames(data) == "Distance"], as.numeric(as.character(data[,colnames(data) == "X0.09"])), type="l", col="magenta")
}

legend("topleft",c('97%','95%', '93%','91%'), pch=c(16,16,16,16), lty=c(1,1,1,1),
col=c('blue','green','red','magenta'),ncol=1)

devname = dev.off() 
